@@ -1,7 +1,10 @@
 from __future__ import annotations  # for python 3.8
+
+from typing import Final
+
 from agstoolbox.core.version.version import Version
 
-EDITOR_FILE_NAME = 'AGSEditor.exe'
+EDITOR_FILE_NAME: Final[str] = 'AGSEditor.exe'
 
 
 class AgsEditor:
