@@ -2,10 +2,12 @@
 import os.path
 import sys
 
+from agstoolbox.core.utils.pyinstaller_hacks import is_running_from_pyinstaller, get_extracted_path
+
 # am I running from pyinstaller ?
-if getattr(sys, 'frozen', False):
+if is_running_from_pyinstaller():
     # yes, running from pyinstaller
-    data_path = os.path.join(os.path.join(sys._MEIPASS), 'data')  # pylint: disable=no-member
+    data_path = os.path.join(get_extracted_path(), 'data')
 elif __file__:
     # no, this is the realworld
     data_path = os.path.join(os.path.dirname(__file__), 'data')
